@@ -123,7 +123,9 @@ def path_type(path):
     if not path or not find_var(path[0]):
         return None, None
     kind = ''
-    asn1_name = VARIABLES[find_var(path[0])].ReferencedTypeName
+    vartype, _ = VARIABLES[find_var(path[0])]
+    asn1_name = vartype.ReferencedTypeName
+    #asn1_name = VARIABLES[find_var(path[0])].ReferencedTypeName
     # Get ASN.1 type of the first element
     current = TYPES[asn1_name].type
     if len(path) > 1:
@@ -977,7 +979,7 @@ def inner_procedure(proc):
     VARIABLES.update(proc.variables)
     # Also add procedure parameters in scope
     for var in proc.fpar:
-        VARIABLES.update({var['name']: var['type']})
+        VARIABLES.update({var['name']: (var['type'], None)})
 
     # Build the procedure signature
     pi_header = 'procedure {proc_name}'.format(proc_name=proc.inputString)
@@ -1004,10 +1006,17 @@ def inner_procedure(proc):
             local_decl.extend(inner_local)
             code.extend(inner_code)
         code.append(pi_header + ' is')
-        for var_name, var_type in proc.variables.viewitems():
+        for var_name, (var_type, def_value) in proc.variables.viewitems():
             typename = var_type.ReferencedTypeName.replace('-', '_')
-            code.append('l_{name} : asn1Scc{sort};'.format(
-                name=var_name, sort=typename))
+            if def_value:
+                # Expression must be a ground expression, i.e. must not
+                # require temporary variable to store computed result
+                dst, dstr, dlocal = decipher_expression(def_value)
+                assert not dst and not dlocal, 'Ground expression error'
+            code.append('l_{name} : asn1Scc{sort}{default};'.format(
+                name=var_name,
+                sort=typename,
+                default=' := ' + dstr if def_value else ''))
         tr_code, tr_decl = transition(proc.content.start.transition)
         # Generate code for the floating labels
         code_labels = []
@@ -1065,9 +1074,17 @@ def generate(process):
 
     # Generate the code to declare process-level variables
     process_level_decl = []
-    for var_name, var_type in VARIABLES.iteritems():
-        process_level_decl.append('l_{n} : aliased asn1Scc{t};'.format(
-            n=var_name, t=var_type.ReferencedTypeName.replace('-','_')))
+    for var_name, (var_type, def_value) in process.variables.viewitems():
+        if def_value:
+            # Expression must be a ground expression, i.e. must not
+            # require temporary variable to store computed result
+            dst, dstr, dlocal = decipher_expression(def_value)
+            assert not dst and not dlocal, 'DCL: Expecting a ground expression'
+        process_level_decl.append(
+                'l_{n} : aliased asn1Scc{t}{default};'.format(
+                        n=var_name,
+                        t=var_type.ReferencedTypeName.replace('-','_'),
+                        default=' := ' + dstr if def_value else ''))
 
     # Add the process states list to the process-level variables
     states_decl = 'type states is ('
