@@ -19,7 +19,7 @@
 
 __all__ = ['Input', 'Output', 'State', 'Task', 'ProcedureCall', 'Label',
            'Decision', 'DecisionAnswer', 'Join', 'Start', 'TextSymbol',
-           'Procedure', 'ProcedureStart', 'ProcedureStop']
+           'Procedure', 'ProcedureStart', 'ProcedureStop', 'ASN1Viewer']
 
 from genericSymbols import(
         HorizontalSymbol, VerticalSymbol, Connection, Comment)
@@ -730,7 +730,7 @@ class ProcedureCall(VerticalSymbol, object):
         ''' Return the text corresponding to the SDL PR notation '''
         comment = repr(self.comment) if self.comment else ';'
         pos = self.scenePos()
-        return ('/* CIF PROCEDURE ({x}, {y}), ({w}, {h}) */\n'
+        return ('/* CIF PROCEDURECALL ({x}, {y}), ({w}, {h}) */\n'
                 '{hlink}'
                 'CALL {p}{comment}'.format(p=str(self.text),
                     hlink=repr(self.text),
@@ -810,6 +810,14 @@ class TextSymbol(HorizontalSymbol, object):
                     h=int(self.boundingRect().height())))
 
 
+class ASN1Viewer(TextSymbol):
+    ''' Text symbol with dedicated text highlighting set of words for ASN.1 '''
+    blackbold = ['\\b{}\\b'.format(word) for word in (
+                 'DEFINITIONS', 'AUTOMATIC', 'TAGS', 'BEGIN', 'END', 'INTEGER',
+                 'OCTET', 'STRING', 'BIT', 'REAL', 'SEQUENCE', 'OF', 'WITH',
+                 'IMPORTS', 'FROM', 'SIZE', 'CHOICE', 'BOOLEAN')]
+
+
 # pylint: disable=R0904
 class State(VerticalSymbol, object):
     ''' SDL STATE Symbol '''
